import subprocess

def check_output(cmd, log):
    return subprocess.check_output(cmd, stderr=log, universal_newlines=True)


def check_call(cmd, log):
    subprocess.check_call(cmd, stdout=log, stderr=subprocess.STDOUT)

vboxmanage = r'c:\Program Files\Oracle\VirtualBox\VBoxManage.exe'
logfile = r'c:\temp\test.log'
dhcp_name = 'HostInterfaceNetworking-VirtualBox Host-Only Ethernet Adapter'
hostif_name = 'VirtualBox Host-Only Ethernet Adapter'


def list_dhcp_servers(log):
    return check_output([vboxmanage, 'list', 'dhcpservers'], log)

def list_hostonlyifs(log):
    return check_output([vboxmanage, 'list', 'hostonlyifs'], log)

with open(logfile, 'w') as log:

    # do we have a dhcp server?
    if dhcp_name + '\n' in list_dhcp_servers(log):
        print('removing: %s' % dhcp_name)
        check_call([vboxmanage, 'dhcpserver', 'remove', '--netname', dhcp_name], log)

    # do we have a hostonly network card?        
    if hostif_name + '\n' in list_hostonlyifs(log):
        print('removing: %s' % hostif_name)
        check_call([vboxmanage, 'hostonlyif', 'remove', hostif_name], log)

    # configure         
    check_call([vboxmanage, 'hostonlyif', 'create'], log)
    cmd = vboxmanage + ' hostonlyif ipconfig "VirtualBox Host-Only Ethernet Adapter" --ip 192.168.56.1 --netmask 255.255.255.0'
    check_call(cmd, log)
    cmd = vboxmanage + ' dhcpserver add --ifname "VirtualBox Host-Only Ethernet Adapter" --ip 192.168.56.2 --netmask 255.255.255.0 --lowerip 192.168.56.3 --upperip 192.168.56.254'
    check_call(cmd, log)
    cmd = vboxmanage + ' dhcpserver modify --netname "HostInterfaceNetworking-VirtualBox Host-Only Ethernet Adapter" --enable'
    check_call(cmd, log)
    # show result
    print(list_dhcp_servers(log))
    print('====================')
    print(list_hostonlyifs(log))
